PAWpySeed: pawpyseed.core.gaunt Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Variables
pawpyseed.core.gaunt Namespace Reference

## Variables
| gcs = np.zeros([4,4,4,7,4])
| facs = np.zeros([4,4,4,7,4])
| val = N(gaunt(l1,l2,l3,m1,m2,-m1-m2))
| val2 = N(wigner_3j(l1,l2,l3,0,0,0))*N(wigner_3j(l1,l2,l3,-m1,m2,m1-m2))
| val3 = np.sqrt((2*l1+1)*(2*l2+1)*(2*l3+1)/4/np.pi)
| f = open('gaunt.c', 'w')

## Detailed Description

    \file
    Python script for generating Gaunt coefficients and factors used for offsite
    partial wave overlap integrals.

## Variable Documentation

pawpyseed.core.gaunt.f = open('gaunt.c', 'w')

pawpyseed.core.gaunt.facs = np.zeros([4,4,4,7,4])

pawpyseed.core.gaunt.gcs = np.zeros([4,4,4,7,4])

pawpyseed.core.gaunt.val = N(gaunt(l1,l2,l3,m1,m2,-m1-m2))

pawpyseed.core.gaunt.val2 = N(wigner_3j(l1,l2,l3,0,0,0))*N(wigner_3j(l1,l2,l3,-m1,m2,m1-m2))

pawpyseed.core.gaunt.val3 = np.sqrt((2*l1+1)*(2*l2+1)*(2*l3+1)/4/np.pi)